@@ -1,11 +1,9 @@
 # -*- encoding=utf8 -*-
 import sys
-from pathlib import Path
-sys.path.append( Path( __file__ ).resolve().parent )
 
 import datetime as dt, time, re, calendar, sys
-from utils import *
-from wull import wull, iswull, WULL
+from .utils import *
+from .wull import wull, iswull, WULL
 from datetime import datetime
 
 if sys.version_info.major >=3 and sys.version_info.minor>=8:
